@@ -43,10 +43,6 @@
 #include <osmocom/vty/misc.h>
 #include <osmocom/vty/stats.h>
 
-#ifdef BUILD_IU
-#include <osmocom/ranap/iu_client.h>
-#endif
-
 #include <osmocom/msc/vty.h>
 #include <osmocom/msc/gsm_data.h>
 #include <osmocom/msc/gsm_subscriber.h>
@@ -815,9 +811,6 @@ static int config_write_msc(struct vty *vty)
 	}
 
 	mgcp_client_config_write(vty, " ");
-#ifdef BUILD_IU
-	ranap_iu_vty_config_write(vty, " ");
-#endif
 
 	neighbor_ident_vty_write(vty);
 
@@ -1055,9 +1048,9 @@ static void vty_dump_one_subscr(struct vty *vty, struct vlr_subscr *vsub,
 		MSC_VTY_DUMP(vty, offset, "Expires: never%s",
 			     VTY_NEWLINE);
 	} else if (osmo_clock_gettime(CLOCK_MONOTONIC, &now) == 0) {
-		MSC_VTY_DUMP(vty, offset, "Expires: in %ld min %ld sec%s",
-			     (vsub->expire_lu - now.tv_sec) / 60,
-			     (vsub->expire_lu - now.tv_sec) % 60,
+		MSC_VTY_DUMP(vty, offset, "Expires: in %lld min %lld sec%s",
+			     (long long int) ((vsub->expire_lu - now.tv_sec) / 60),
+			     (long long int) ((vsub->expire_lu - now.tv_sec) % 60),
 			     VTY_NEWLINE);
 	}
 
@@ -1603,6 +1596,9 @@ DEFUN(subscriber_silent_call_start,
 	case -ENODEV:
 		vty_out(vty, "%% Subscriber not attached%s", VTY_NEWLINE);
 		break;
+	case -EBUSY:
+		vty_out(vty, "%% Subscriber already has an active connection%s", VTY_NEWLINE);
+		break;
 	default:
 		if (rc)
 			vty_out(vty, "%% Cannot start silent call (rc=%d)%s", rc, VTY_NEWLINE);
@@ -2125,9 +2121,6 @@ void msc_vty_init(struct gsm_network *msc_network)
 	/* Deprecated: Old MGCP config without pooling support in MSC node: */
 	mgcp_client_vty_init(msc_network, MSC_NODE, msc_network->mgw.conf);
 
-#ifdef BUILD_IU
-	ranap_iu_vty_init(MSC_NODE, (enum ranap_nsap_addr_enc*)&msc_network->iu.rab_assign_addr_enc);
-#endif
 	sgs_vty_init();
 	smsc_vty_init(msc_network);
 	asci_vty_init(msc_network);
