@@ -1,25 +1,21 @@
 /* RANAP encoding and decoding for MSC */
 /*
- * (C) 2019 by sysmocom - s.m.f.c. GmbH <info@sysmocom.de>
+ * (C) 2019 by sysmocom - s.f.m.c. GmbH <info@sysmocom.de>
  * All Rights Reserved
  *
  * Author: Neels Hofmeyr
  *
- * SPDX-License-Identifier: GPL-2.0+
+ * SPDX-License-Identifier: AGPL-3.0+
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * GNU Affero General Public License for more details.
  */
 
 #include <asn1c/asn1helpers.h>
@@ -27,6 +23,7 @@
 #include <osmocom/core/prim.h>
 #include <osmocom/core/byteswap.h>
 #include <osmocom/crypt/auth.h>
+#include <osmocom/crypt/utran_cipher.h>
 #include <osmocom/gsm/gsm48.h>
 
 #include <osmocom/ranap/ranap_common_cn.h>
@@ -156,7 +153,16 @@ static int ran_iu_decode_rab_assignment_response_decode_setup_ies(struct ran_dec
 		.msg_type = RAN_MSG_ASSIGNMENT_COMPLETE,
 		.msg_name = "RANAP RAB Assignment Response",
 		.assignment_complete = {
-			.codec = CODEC_AMR_8000_1,
+			/* For codec compatibility resolution, indicate AMR-FR */
+			.codec_present = true,
+			.codec = {
+				.fi = true,
+				.type = GSM0808_SCT_FR3,
+				.cfg = GSM0808_SC_CFG_DEFAULT_FR_AMR,
+			},
+			/* Indicate that (at least) the first MGW endpoint towards RAN needs to expect VND.3GPP.IUFP
+			 * that encapsulates the AMR-FR RTP payload. */
+			.codec_with_iuup = true,
 		},
 	};
 	if (osmo_sockaddr_str_from_str(&ran_dec_msg->assignment_complete.remote_rtp, addr, port)) {
@@ -374,14 +380,21 @@ static struct msgb *ran_iu_make_rab_assignment(struct osmo_fsm_inst *caller_fi,
 static struct msgb *ran_iu_make_security_mode_command(struct osmo_fsm_inst *caller_fi,
 						      const struct ran_cipher_mode_command *cm)
 {
+	/* TODO: make the choice of available UIA algorithms configurable */
+	const uint8_t uia_mask = (1 << OSMO_UTRAN_UIA1) | (1 << OSMO_UTRAN_UIA2);
+	const uint8_t uea_mask = cm->utran.uea_encryption_mask & ~(1 << OSMO_UTRAN_UEA0);
+	bool use_encryption = uea_mask != 0x00;
 
 	LOG_RAN_IU_ENC(caller_fi, LOGL_DEBUG, "Tx RANAP SECURITY MODE COMMAND to RNC, IK=%s, CK=%s\n",
 			osmo_hexdump_nospc(cm->vec->ik, 16),
-			cm->utran.uea_encryption_mask > 0x01 ? osmo_hexdump_nospc(cm->vec->ck, 16) : "NONE");
+			use_encryption ? osmo_hexdump_nospc(cm->vec->ck, 16) : "NONE");
 	/* TODO: Do we need to check if the UE supports all of the algorithms and build an intersection like
 	 * in the case of A5? */
-	return ranap_new_msg_sec_mod_cmd2(cm->vec->ik, cm->utran.uea_encryption_mask > 0x01 ? cm->vec->ck : NULL,
-					  RANAP_KeyStatus_new, 0x06, cm->utran.uea_encryption_mask);
+	return ranap_new_msg_sec_mod_cmd2(cm->vec->ik,
+					  use_encryption ? cm->vec->ck : NULL,
+					  RANAP_KeyStatus_new,
+					  (uia_mask << 1), /* API treats LSB as UIA0 */
+					  uea_mask);
 }
 
 
